<p align="center">
    <img src="https://codealchemi.com/images/jserv.png" width="256px" height="256px">
</p>

<h1 align="center">
    jServ Python Library
</h1>

<h3 align="center">
    A project by codealchemi
</h3>

<p align="center">
    <img src="https://img.shields.io/github/license/Codealchemi/jServ-python-lib?style=flat-square">
    <img src="https://img.shields.io/pypi/v/jServ-python?style=flat-square">
    <img src="https://img.shields.io/pypi/pyversions/jServ-python?style=flat-square">
    <img src="https://img.shields.io/github/languages/code-size/Codealchemi/jServ-python-lib?style=flat-square">
</p>


Python library for interfacing with jServ

Information about jServ can be found at <a href="https://github.com/Codealchemi/jServ">https://github.com/Codealchemi/jServ</a>

<a href="https://codealchemi.com">codealchemi</a>
